@@ -18,13 +18,14 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afdoor.c,v 1.1 1999/06/06 11:36:17 bazsi Exp $
+ * $Id: afdoor.c,v 1.2 1999/06/15 20:32:34 bazsi Exp $
  *
  ***************************************************************************/
 
 #include "afdoor.h"
 #include "sources.h"
 #include "format.h"
+#include "cfgfile.h"
 
 #include "afdoor.c.x"
 
@@ -34,7 +35,9 @@
      (super log_source_driver)
      (vars
        (name string)
-       (fd . int)))
+       (pipe array (simple int) 2)
+       (pipe_fd object io_fd)
+       (door simple int)))
 */
 
 #ifdef HAVE_DOOR_H
@@ -51,8 +54,10 @@
 void afdoor_server_proc(void *cookie, char *argp, size_t arg_size, door_desc_t *dp, size_t n_desc)
 {
 	CAST(afdoor_source, handler, cookie);
-	struct log_info *msg = make_log_info(c_format(argp, arg_size));
-	HANDLE_LOG(handler, msg);
+	if (argp) {
+		write(handler->pipe[1], argp, arg_size);
+	}
+	door_return(NULL, 0, NULL, 0);
 }
 
 static int do_init_afdoor_source(struct log_handler *c, struct syslog_conf *cfg)
@@ -71,13 +76,30 @@ static int do_init_afdoor_source(struct log_handler *c, struct syslog_conf *cfg)
 		close(fd);
 	}
 	fdetach(self->name->data);
-	fd = door_create(afdoor_server_proc, (void *) c, 0);
-	if (fd == -1) {
-		werror("Cannot initialize door server %S (%z)\n", self->name, strerror(errno));
+	if (pipe(self->pipe) != -1) {
+		fd = door_create(afdoor_server_proc, (void *) c, 0);
+		if (fd == -1) {
+			werror("do_init_afdoor_source: Cannot initialize door server %S (%z)\n", self->name, strerror(errno));
+			close(self->pipe[0]);
+			close(self->pipe[1]);
+			return ST_FAIL | ST_QUIT;
+		}
+		if (fattach(fd, self->name->data) == -1) {
+			werror("do_init_afdoor_source: Cannot attach door to %S (%z)\n", self->name, strerror(errno));
+			close(self->pipe[0]);
+			close(self->pipe[1]);
+			return ST_FAIL | ST_QUIT;
+		}
+		self->door = fd;
+		self->pipe_fd = io_read(make_io_fd(cfg->backend, self->pipe[0]), 
+					make_log_reader(0, c),
+					NULL);
+		REMEMBER_RESOURCE(cfg->resources, &self->pipe_fd->super.super);
+	}
+	else {
+		werror("do_init_afdoor_source: Error creating pipe (%z)\n", strerror(errno));
 		return ST_FAIL | ST_QUIT;
 	}
-	fattach(fd, self->name->data);
-	self->fd = fd;
 	return ST_OK | ST_GOON;
 }
 
@@ -85,7 +107,7 @@ static int do_destroy_afdoor_source(struct log_handler *c, struct syslog_conf *c
 {
 	CAST(afdoor_source, self, c);
 
-	door_revoke(self->fd);
+	door_revoke(self->door);
 	return ST_OK | ST_GOON;
 }
 
@@ -104,7 +126,7 @@ struct log_source_driver *make_afdoor_source(const char *name)
 	self->super.super.super.destroy = do_destroy_afdoor_source;
 	self->super.super.super.handler = do_handle_afdoor_source;
 	self->name = c_format_cstring("%z", name);
-	self->fd = -1;
+	self->door = -1;
 	return &self->super;
 }
 
@@ -123,7 +145,7 @@ struct log_source_driver *make_afdoor_source(const char *name)
 
 	self->super.super.super.init = do_init_afdoor_source;
 	self->name = c_format_cstring("%z", name);
-	self->fd = -1;
+	self->door = -1;
 	return &self->super;
 }
 
