@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 1998 BalaBit Computing
+ * Copyright (c) 1999 BalaBit Computing
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,34 +16,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * Based on the original nsyslog by
+ * Inspired by nsyslog, originally written by Darren Reed.
  *
- * Copyright (C) 1997 by Darren Reed.
+ * $Id: afdoor.h,v 1.1 1999/06/06 11:36:17 bazsi Exp $
  *
- * Redistribution and use in source and binary forms are permitted
- * provided that this notice is preserved and due credit is given
- * to the original author and the contributors.
  ***************************************************************************/
 
-#ifndef __AFDOOR_H
-#define __AFDOOR_H
+#ifndef __AFDOOR_H_INCLUDED
+#define __AFDOOR_H_INCLUDED
 
-#include "config.h"
-#include "ftable.h"
+#include "syslog-ng.h"
 
-typedef struct doorspec {
-	struct doorspec *ds_next;
-	int ds_mode;
-	int ds_cnt;	/* reference count */
-	int ds_fd;	/* fd to the open file */
-	char *ds_path;	/* path to the sun stream file */
-} doorspec_t;
-
-extern	doorspec_t	*dslist;
-
-extern	void	afdoor_open_door	__P((doorspec_t *));
-extern	void	afdoor_close_door	__P((doorspec_t *));
-extern	int	afdoor_check_fd		__P((int, filetable_entry_t *));
+struct log_source_driver *make_afdoor_source(const char *name);
 
 #endif
-
