@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 1998 BalaBit Computing
+ * Copyright (c) 1999 BalaBit Computing
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,33 +16,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * Based on the original nsyslog by
+ * Inspired by nsyslog, originally written by Darren Reed.
  *
- * Copyright (C) 1997 by Darren Reed.
+ * $Id: afstreams.h,v 1.1 1999/06/15 20:32:34 bazsi Exp $
  *
- * Redistribution and use in source and binary forms are permitted
- * provided that this notice is preserved and due credit is given
- * to the original author and the contributors.
  ***************************************************************************/
 
-#ifndef __AFSTREAMS_H
-#define __AFSTREAMS_H
+#ifndef __AFSTREAMS_H_INCLUDED
+#define __AFSTREAMS_H_INCLUDED
 
-#include "config.h"
-#include "ftable.h"
+#include "syslog-ng.h"
 
-typedef struct streamspec {
-	struct streamspec *ss_next;
-	int ss_mode;
-	int ss_cnt;	/* reference count */
-	int ss_fd;	/* fd to the open file */
-	char *ss_path;	/* path to the sun stream file */
-} streamspec_t;
-
-extern	streamspec_t	*sslist;
-
-extern	void	afstreams_open_stream	__P((streamspec_t *));
-extern	int	afstreams_check_fd	__P((int, filetable_entry_t *));
+struct log_source_driver *make_afstreams_source(const char *name);
 
 #endif
-
