@@ -1,6 +1,7 @@
 /***************************************************************************
  *
- * Copyright (c) 1998 BalaBit Computing
+ * Portions copyright (C) 1998-1999 Niels Mller
+ * Copyright (c) 1999 BalaBit Computing
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,26 +17,23 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * Based on the original nsyslog by
+ * Inspired by nsyslog, originally written by Darren Reed.
  *
- * Copyright (C) 1997 by Darren Reed.
+ * $Id: utils.h,v 1.5 1999/05/06 15:03:33 bazsi Exp $
  *
- * Redistribution and use in source and binary forms are permitted
- * provided that this notice is preserved and due credit is given
- * to the original author and the contributors.
  ***************************************************************************/
 
-#ifndef __UTILS_H
-#define __UTILS_H
+#ifndef __UTILS_H_INCLUDED
+#define __UTILS_H_INCLUDED
 
-#include "config.h"
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
 
-extern	char		*get_shorthostname __P((void));
-extern	char		*get_fullhostname __P((void));
+char *getshorthostname(char *buf, size_t bufsize);
 
-extern	struct	in_addr	getipv4addr __P((char *));
-extern	struct	in_addr getipmask __P((char *));
-extern	u_short		getportnum __P((char *, char *));
-extern	char		*chomp __P((char *));
+#ifndef HAVE_INET_ATON
+int inet_aton(const char *cp, struct in_addr *addr);
+#endif
 
 #endif
